<?xml version="1.0"?>

<xsl:stylesheet version="1.0"
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 xmlns:dir="http://apache.org/cocoon/directory/2.0"
 xmlns:path="http://snipsnap.org/org.radeox.xsltExample.Path"
 xmlns:radeox="http://snipsnap.org/org.radeox.xsltExample.Renderer"
 xmlns:source="http://apache.org/cocoon/source/1.0">

<xsl:param name="rev"/>

<!-- editor-view templates to display your doctype. overriding editor-components.xsl version -->

<xsl:template match="*" priority="6" mode="wiki-view">
 <xsl:copy>
  <xsl:apply-templates mode="wiki-view"/>
 </xsl:copy>
</xsl:template>

<xsl:template match="a" priority="6" mode="wiki-view">
 <a>
			<xsl:attribute name="href">
			      <xsl:choose>
			       <xsl:when test="starts-with(@href,'/')">
			        <xsl:value-of select="concat(path:pathToRoot(string($target)),@href)"/>
			       </xsl:when>
			       <xsl:otherwise>
			        <xsl:value-of select="@href"/>
			       </xsl:otherwise>
			      </xsl:choose>
			</xsl:attribute>
			<xsl:apply-templates select="text()" mode="wiki-view"/>
 </a>
</xsl:template>


	<xsl:template match="content" mode="editor-view" priority="6">

		<xsl:choose>
			<xsl:when test="$rev=''">
 		<xsl:if test="not(following-sibling::content)">
		<div>
		<xsl:apply-templates select="radeox:xsltRender(translate(.,'&#13;','&#10;'))" mode="wiki-view"/>
		<xsl:call-template name="references"/>
		</div>
                </xsl:if>
			</xsl:when>
			<xsl:otherwise>
 		<xsl:if test="1+count(preceding-sibling::content)=$rev">
		<div>
		<xsl:apply-templates select="radeox:xsltRender(translate(.,'&#13;','&#10;'))" mode="wiki-view"/>
		<xsl:call-template name="references"/>
		</div>
                </xsl:if>
			</xsl:otherwise>
		</xsl:choose>
  </xsl:template>

	<xsl:template match="content" mode="editor-view" priority="5">
		<xsl:choose>
			<xsl:when test="$rev=''">
 		<xsl:if test="not(following-sibling::content)">
		<div>
		<xsl:copy-of select="radeox:xsltRender(translate(.,'&#13;','&#10;'))"/>
		<xsl:call-template name="references"/>
		</div>
                </xsl:if>
			</xsl:when>
			<xsl:otherwise>
 		<xsl:if test="1+count(preceding-sibling::content)=$rev">
		<div>
		<xsl:copy-of select="radeox:xsltRender(translate(.,'&#13;','&#10;'))"/>
		<xsl:call-template name="references"/>
		</div>
                </xsl:if>
			</xsl:otherwise>
		</xsl:choose>
  </xsl:template>
  
	<xsl:template match="title" mode="editor-view" priority="5">
		<xsl:choose>
			<xsl:when test="$rev=''">
 		<xsl:if test="not(following-sibling::title)">
		<div class="title"><xsl:apply-templates/><xsl:call-template name="revManager"/></div>
                </xsl:if>
			</xsl:when>
			<xsl:when test="1+count(preceding-sibling::title)=$rev">
		<div class="title"><xsl:apply-templates/><xsl:call-template name="revManager"/></div>
			</xsl:when>
			<xsl:otherwise>
			</xsl:otherwise>
		</xsl:choose>
  </xsl:template>

	<xsl:template name="references" mode="editor-view" priority="5">
		<hr/>
		<xsl:if test="//references/reference">
		<div>
		<p>Users came to <i><xsl:value-of select="$target"/></i> from:</p>
		<xsl:variable name="pathToRoot" select="path:pathToRoot(string($target))"/>
		<ul>
		<xsl:for-each select="//references/reference">
		 <li><a href="{concat($pathToRoot,@from)}"><xsl:value-of select="@from"/></a></li>
		</xsl:for-each>
		</ul>
		</div>
		</xsl:if>
        </xsl:template>


  <xsl:template name="revManager">
 <!-- $target and $behaviour are defined by editor-utils.xsl. editor-utils.xsl was called before the current xsl by editor-components.xsl. So I can use it here --> 
   <xsl:if test="$behaviour='see'">
 <!-- path:removePath is in fact removePath() from org.radeox.xsltExample.PathRemover. It returns just the topic name, removing all the path to this topic -->
   <form action="{path:removePath(string($target))}" method="get">
   <xsl:value-of select="'(revision: '"/>
   <select name="rev"  onChange="this.form.submit()">

    <xsl:for-each select="preceding-sibling::title">
     <xsl:variable name="revNumber" select="1+count(preceding-sibling::title)"/>
     <option value="{$revNumber}">
      <xsl:value-of select="$revNumber"/>
     </option>
    </xsl:for-each>

    <xsl:variable name="revNumber" select="1+count(preceding-sibling::title)"/>
    <option selected="true" value="{$revNumber}">
      <xsl:value-of select="$revNumber"/>
      <xsl:if test="not(following-sibling::title)">
      <xsl:value-of select="' (latest)'"/>
      </xsl:if>
    </option>

    <xsl:for-each select="following-sibling::title">
     <xsl:variable name="revNumber" select="1+count(preceding-sibling::title)"/>
     <option value="{$revNumber}">
      <xsl:value-of select="$revNumber"/>
      <xsl:if test="not(following-sibling::title)">
      <xsl:value-of select="'(latest)'"/>
      </xsl:if>
     </option>
    </xsl:for-each>

   </select>
   <xsl:value-of select="')'"/>
   </form>
   </xsl:if>
  </xsl:template>

<!-- your form for editing 'page' doctype content, handles the 'wiki' sub-editor for 'get' and 'new' behaviours -->
	<xsl:template match="editor[@sub='wiki']/instance[@behaviour='get' or @behaviour='new']/page" mode="sub-editor">
		<div class="block">
			<span class="tab">Wiki Editor</span>
			<div class="content">
				<form method="get" accept-charset="UTF-8">
					<xsl:attribute name="action"><xsl:value-of select="$command-base"/><xsl:value-of select="$config/command[@behaviour = 'pre']"/></xsl:attribute>
					<div class="block">
						<span class="tab">Title</span>
						<div class="field">
							<input name="title" size="40"  onchange="changed=true;" value="{normalize-space(title[count(following-sibling::title)=0])}"/>
						</div>
					</div>
					<div class="block">
						<span class="tab">Body</span>
						<div class="field">
							<textarea name="content" rows="20" cols="80" xml:space="preserve" onchange="changed=true;"><xsl:apply-templates select="content[count(following-sibling::content)=0]" mode="wiki"/></textarea>
						</div>
					</div>
					<div class="block">
						<span class="tab">Save as</span>
						<div class="field">
							<input type="text" name="target" value="{$newfile}" size="40" title="Note: to make a new directory, prepend the filename with a directory path"/>
						</div>
						<div class="block" style="text-align:right">
							<input class="submit" type="submit" value="{$config/button[@behaviour = $behaviour]}"/>
						</div>
					</div>						
				</form>	
			</div>
		</div>
  </xsl:template>

	<xsl:template match="editor[@sub='wiki']/instance[@behaviour='put']/page" mode="sub-editor"/>

<!-- your template for previewing 'page' doctype content, handles the 'wiki' sub-editor for 'pre' behaviour -->
	<xsl:template match="editor[@sub='wiki']/instance[@behaviour='pre']/page" mode="sub-editor">
		<div class="block">
			<span class="tab">Editor Preview</span>
			<div class="content"><xsl:apply-templates mode="editor-view"/></div>
		</div>
		<div class="confirm">
			<span class="tab">Confirm</span>
			<div class="content" id="center">
				<xsl:text>Are you sure you want to save these changes?</xsl:text>
				<form method="get">
					<xsl:attribute name="action"><xsl:value-of select="$command-base"/><xsl:value-of select="$config/command[@behaviour = 'put']"/></xsl:attribute>
					<input name="title" type="hidden" value="{normalize-space(title)}"/>
					<textarea class="hidden" name="content" xml:space="preserve" onchange="changed=true;"><xsl:value-of select="content[1]"/> </textarea>
					<input name="target" type="hidden" value="{$newfile}"/>
					<input type="button" value="{$config/button[@behaviour = 'back']}" onClick="history.back()" title="{$config/button[@behaviour = 'back']/@tip}" class="button"/> 
					<span class="hspace"> </span>
					<input name="{$config/button[@behaviour = $behaviour]}" class="submit" type="submit" value="{$config/button[@behaviour = $behaviour]}"/>
                                        <br/><input type="checkbox" value="false" name="handleRevisions"/>Remove Older Revisions?
				</form>	
			</div>
		</div>
  </xsl:template>

	<xsl:template match="b|i|a|strong|em|ul|ol|li" mode="wiki"><xsl:copy><xsl:apply-templates select="@*|*|text()"/></xsl:copy></xsl:template>

	<xsl:template match="br" mode="wiki">
		<xsl:text>
</xsl:text>
	</xsl:template><!---->

	<xsl:template match="para" mode="wiki"><!-- strips 'br' tags, so they need a CR after them to survive! -->
		<xsl:apply-templates mode="wiki"/>
		<xsl:text>

</xsl:text>
	</xsl:template>

</xsl:stylesheet>
