<?xml version="1.0"?>

<xsl:stylesheet version="1.0"
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 xmlns:sch="http://www.ascc.net/xml/schematron" 
 xmlns:zvon="http://zvon.org/schematron"
 xmlns:request="http://xml.apache.org/cocoon/requestgenerator/2.0"
 xmlns:sunshine="http://cocoon.apache.org/sunshine/1.0"
 xmlns:radeox="http://snipsnap.org/org.radeox.xsltExample.Renderer"
 xmlns:path="http://snipsnap.org/org.radeox.xsltExample.Path"
 xmlns:source="http://apache.org/cocoon/source/1.0"
 >

	<xsl:param name="docsBase">docs</xsl:param>
	<xsl:param name="referencesBase">references</xsl:param>
	<xsl:param name="handleRevisions">true</xsl:param>
	<xsl:param name="target"/>
	<xsl:variable name="quote">'</xsl:variable>
	<xsl:variable name="doublequote">"</xsl:variable>

<xsl:template name="getPath">
  <xsl:param name="topicPath"/>
  <xsl:param name="path"></xsl:param>
  <xsl:choose>
   <xsl:when test="not(contains($topicPath,'/'))">
    <xsl:value-of select="$path"/>
   </xsl:when> 
   <xsl:otherwise> 
    <xsl:variable name="directoryToAppend">
     <xsl:value-of select="substring-before($topicPath,'/')"/>
    </xsl:variable>
    <xsl:call-template name="getPath">
     <xsl:with-param name="topicPath">
      <xsl:value-of select="substring-after($topicPath,'/')"/>
     </xsl:with-param>
     <xsl:with-param name="path">
      <xsl:value-of select="concat($path,$directoryToAppend,'/')"/>
     </xsl:with-param>
    </xsl:call-template>
   </xsl:otherwise> 
  </xsl:choose>
</xsl:template>


<!-- 

	This StyleSheet converts the output of the Validator and wraps it 
	with 'source:write' tags, so the SourceWritingTransformer can save it
	only if there have been no validation errors.

	NB. the indentation of these templates effects the output document
	
	NB. it can get tricky to decide which namespaces need to be in which stylesheet, 
	to make sure the wrong ones don't end up being written to source
		
-->

 
<xsl:template match="/">
 <xsl:apply-templates/>
</xsl:template>

<xsl:template match="editor">
	<editor>
		<xsl:copy-of select="@*"/>
		 <instance behaviour="{instance/@behaviour}" target="{instance/@target}">
			<xsl:apply-templates select="instance/*"/>
 		 <xsl:if test="instance/@behaviour='put'">
			<xsl:call-template name="handleTopicWriting"/>
			<xsl:call-template name="handleReferencesWriting"/>
		 </xsl:if>			
                  </instance>
		<xsl:apply-templates select="validationResult"/>
	</editor>
</xsl:template>

  <xsl:template match="*"><xsl:copy-of select="."/></xsl:template>
  <xsl:template match="instance/page/*" priority="-1" mode="topicWriting"></xsl:template>

  <xsl:template match="instance/page/title" mode="topicWriting"><xsl:copy-of select="."/></xsl:template>
  <xsl:template match="instance/page/content" mode="topicWriting"><xsl:copy><xsl:value-of select="para"/></xsl:copy></xsl:template>

 <xsl:template name="handleTopicWriting">
  <xsl:choose>
   <xsl:when test="$handleRevisions='true'">
    <sunshine:insert create="true">
     <sunshine:file>
      <xsl:value-of select="concat($docsBase,instance/@target)"/>
     </sunshine:file>
     <sunshine:path>
      <xsl:value-of select="'/page'"/>
     </sunshine:path>
     <sunshine:fragment>
      <xsl:apply-templates select="instance/page/title" mode="topicWriting"/>
      <xsl:apply-templates select="instance/page/content" mode="topicWriting"/>
     </sunshine:fragment>
    </sunshine:insert>
   </xsl:when>
   <xsl:otherwise>
    <source:write src="{concat($docsBase,instance/@target)}" xml:space="preserve" create="true">
     <page>
      <xsl:apply-templates select="instance/page/*" mode="topicWriting"/>
     </page>
    </source:write>
   </xsl:otherwise>
  </xsl:choose>

 </xsl:template>

 <xsl:template name="handleReferencesWriting">
   <xsl:for-each select="radeox:xsltRender(string(instance/page/content/para))//a[not(contains(@href,'://'))]">
    <xsl:variable name="href" select="@href"/>
    <xsl:if test="not(following::a[@href=$href])">
     <xsl:variable name="to">
      <xsl:choose>
       <xsl:when test="starts-with(@href,'/') and path:endsWith(string(@href),'/')">
        <xsl:value-of select="concat(@href,'StartingPoints')"/>
       </xsl:when>
       <xsl:when test="starts-with(@href,'/') and not(path:endsWith(string(@href),'/'))">
        <xsl:value-of select="@href"/>
       </xsl:when>
       <xsl:when test="not(starts-with(@href,'/')) and path:endsWith(string(@href),'/')">
        <xsl:value-of select="concat(path:getPath($target),'/',@href,'StartingPoints')"/>
       </xsl:when>
       <xsl:otherwise>
        <xsl:value-of select="concat(path:getPath($target),'/',@href)"/>
       </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <sunshine:insert create="true">
     <sunshine:file>
        <xsl:value-of select="concat($referencesBase,$to)"/>
     </sunshine:file>
     <sunshine:path>/references</sunshine:path>
     <sunshine:replace>
      <xsl:value-of select="concat('/references/reference[@from=',$quote,$target,$quote,']')"/>
     </sunshine:replace>

     <sunshine:fragment>
        <reference from="{$target}" to="{$to}"/>
     </sunshine:fragment>

    </sunshine:insert>

    </xsl:if>
   </xsl:for-each>

 </xsl:template>

</xsl:stylesheet>
